changeset 3051:ee2654308a57

jp: default to "dark" if background is not set and can't be detected
author Goffi <goffi@goffi.org>
date Thu, 03 Oct 2019 22:17:19 +0200
parents d2a26ec74b31
children 60a63723ecea
files sat_frontends/jp/base.py
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/sat_frontends/jp/base.py	Tue Oct 01 22:54:18 2019 +0200
+++ b/sat_frontends/jp/base.py	Thu Oct 03 22:17:19 2019 +0200
@@ -131,9 +131,9 @@
             for c in expected:
                 ch = sys.stdin.read(1)
                 if ch != c:
                     # background id is not supported
                     # TODO: log something?
-                    return
+                    return 'dark'
             red, green, blue = [int(c, 16)/65535 for c in sys.stdin.read(14).split('/')]
             # '\a' is the last character
             sys.stdin.read(1)
@@ -131,9 +131,9 @@
                 ch = sys.stdin.read(1)
                 if ch != c:
-                    # background id is not supported
+                    # background id is not supported, we default to "dark"
                     # TODO: log something?